Sample of the data. It must constain a column with the data to estimate
and a second column with the domain of each instance.
estimator
One of "total", "mean". Default is "total".
domain
Domain of the sample from which parameter estimation will be done.
replace
Whether the sample to be taken can have repeated instances or not.
alpha
Optional value to calculate estimation error and build 1-alpha
confidence interval.
Details
Data columns must be arranged with interest values on the first column
and domain values on the last column.
Domain parameter can be either numeric or character
and must be equal to one of the values of the domain column of data.
References
Pérez, C. (1999) Técnicas de muestreo estadístico. Teoría, práctica y aplicaciones informáticas. 193-195