syst.estimator: Parameter estimation on a systematic sample
Description
Parameter estimation on a systematic sample
Usage
syst.estimator(
N,
sample,
estimator = c("total", "mean", "proportion", "class total"),
method = c("srs", "strata", "syst"),
alpha,
data,
t
)
Value
A list containing different interest values:
estimator
variance
sampling.error
estimation.error
confint
Arguments
N
Population size
sample
Vector containing the systematic sample
estimator
Estimator to compute. Can be one of "total", "mean", "proportion", "class total". Default is "total".
method
Method of variance estimation. Can be one of "srs", "strata", "syst".
alpha
Optional value to calculate estimation error and build 1-alpha confidence interval.
data
Population data.
t
Number of systematic samples to take with interpenetrating samples method.
Details
Variance estimation has no direct formula in systematic sampling, thus estimation method must be done. Refer to syst.intracorr
and syst.intercorr functions details for more information.
"syst" method uses interpenetrating samples method in which t systematic samples of size=\(\frac{n}{t}\) are taken to estimate. \(\frac{n}{t}\) must be even.
By choosing the start at random for all the samples they can be considered random taken. With this method population data and t must be given.