Learn R Programming

samplingR (version 1.0.1)

syst.intracorr: Intraclass correlation coefficient

Description

Intraclass correlation coefficient

Usage

syst.intracorr(N, n, data)

Value

Intraclass correlation

Arguments

N

Population size

n

Sample size

data

Population data

Details

This value serves as a comparison between systematic and simple random sampling precision.
At value=1 the systematic precision is minimum. At value=0 both sampling methods precision are equal. At value= \(\frac{-1}{n-1}\) systematic precision is maximum.
Summarising at values between 1 and 0 simple random sampling estimation has more precision than systematic, so method="srs" should be set at syst.estimator. The other way method="syst" of interpenetrating samples method is better.

Examples

Run this code
data<-c(1,3,5,2,4,6,2,7,3)
syst.intracorr(9, 3, data)  #0.34375 example 1

Run the code above in your browser using DataLab